PrintTextStyle class

Constructors

PrintTextStyle({int? textSize = 24, bool? underline = false, double? textScaleX = 1.0, double? textScaleY = 1.0, double? letterSpacing = 0, double? lineSpacing = 0, int? topPadding = 0, int? leftPadding = 0, PrintAlign? align = PrintAlign.LEFT, String? font})

Properties

align ↔ PrintAlign?
text alignment
getter/setter pair
font ↔ String?
font file path for custom font
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
leftPadding ↔ int?
left padding
getter/setter pair
letterSpacing ↔ double?
text letter-spacing
getter/setter pair
lineSpacing ↔ double?
text line-spacing
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textScaleX ↔ double?
the horizontal skew factor for text
getter/setter pair
textScaleY ↔ double?
the horizontal scale factor for print text
getter/setter pair
textSize ↔ int?
text font size
getter/setter pair
topPadding ↔ int?
top padding
getter/setter pair
underline ↔ bool?
text underline
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited