MethodChannelNyxPrinter class

An implementation of NyxPrinterPlatform that uses method channels.

Inheritance

Constructors

MethodChannelNyxPrinter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearLabelLearning() → Future<void>
override
configLcd(LcdOpt opt) → Future<void>
override
getPrinterStatus() → Future<int?>
override
getPrinterVersion() → Future<String?>
override
getServiceVersion() → Future<String?>
override
hasLabelLearning() → Future<bool?>
override
labelDetectAuto() → Future<void>
override
labelLocate(int labelHeight, int labelGap) → Future<void>
override
labelLocateAuto() → Future<void>
override
labelPrintEnd() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCashBox() → Future<void>
override
paperBack(int px) → Future<void>
override
paperOut(int px) → Future<void>
override
printBarcode(String data, int width, int height, {BarcodeTextPosition textPosition = BarcodeTextPosition.NO_TEXT, PrintAlign align = PrintAlign.LEFT}) → Future<void>
override
printEndAutoOut() → Future<void>
override
printEscposData(Uint8List data) → Future<void>
override
printImage(Uint8List img, {ImageType type = ImageType.BLACK_WHITE, PrintAlign align = PrintAlign.LEFT}) → Future<void>
override
printQrCode(String data, int width, int height, {PrintAlign align = PrintAlign.LEFT}) → Future<void>
override
printRasterData(Uint8List data) → Future<void>
override
printTableText(List<String> texts, List<void> weights, List<PrintTextStyle> styles) → Future<void>
override
printText(String text, PrintTextStyle? style, {int? textWidth, PrintAlign? align}) → Future<void>
override
showLcdImage(Uint8List img) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited