NyxPrinterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • NyxPrinterPlatform
Implementers

Constructors

NyxPrinterPlatform()
Constructs a NyxPrinterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearLabelLearning() → Future<void>
configLcd(LcdOpt opt) → Future<void>
getPrinterStatus() → Future<int?>
getPrinterVersion() → Future<String?>
getServiceVersion() → Future<String?>
hasLabelLearning() → Future<bool?>
labelDetectAuto() → Future<void>
labelLocate(int labelHeight, int labelGap) → Future<void>
labelLocateAuto() → Future<void>
labelPrintEnd() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCashBox() → Future<void>
paperBack(int px) → Future<void>
paperOut(int px) → Future<void>
printBarcode(String data, int width, int height, {BarcodeTextPosition textPosition = BarcodeTextPosition.NO_TEXT, PrintAlign align = PrintAlign.LEFT}) → Future<void>
printEndAutoOut() → Future<void>
printEscposData(Uint8List data) → Future<void>
printImage(Uint8List img, {ImageType type = ImageType.BLACK_WHITE, PrintAlign align = PrintAlign.LEFT}) → Future<void>
printQrCode(String data, int width, int height, {PrintAlign align = PrintAlign.LEFT}) → Future<void>
printRasterData(Uint8List data) → Future<void>
printTableText(List<String> texts, List<int> weights, List<PrintTextStyle> styles) → Future<void>
printText(String text, PrintTextStyle? style, {int? textWidth, PrintAlign? align}) → Future<void>
showLcdImage(Uint8List img) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ NyxPrinterPlatform
The default instance of NyxPrinterPlatform to use.
getter/setter pair